local addonName, TF = ...

local Loc = LibStub("AceLocale-3.0"):GetLocale("TradeFill")

messageAppear = {}

function checkStacks(stackTable)
    if next(stackTable) == nil then
        return true
    end

    for _, value in pairs(stackTable) do
        if type(value) == "table" then
            if not checkStacks(value) then
                return false
            end
        elseif value ~= 0 then
            return false
        end
    end
    return true
end

function showMessage(message, arg1, arg2, condition)
    if TF.data.setting.message then
        return
    else
        for _, oldMessage in pairs(messageAppear) do
            if oldMessage == message then
                return
            end
        end

        if condition then
            DEFAULT_CHAT_FRAME:AddMessage(TF.signature .. string.format(Loc["CONDITION_MESSAGE"] .. message, arg1, arg2))
        else
            DEFAULT_CHAT_FRAME:AddMessage(TF.signature .. string.format(message, arg1))
        end
        table.insert(messageAppear, message)
    end
end

function ItemCondition(stack, item)
    if TF.data.setting.require == true and  TF.level < item.level then
        local linkIcon = item.link .. " |T" .. GetItemIcon(item.id) .. ":0|t"
        showMessage(Loc["MESSAGE_REQUIRED"], linkIcon, Loc["TOGGLE_REQUIRED"], true)
        return
    else
        for i = 1, stack do
            fillTradeWindow(item, tradePosition())
        end
    end
end

function tradingCondition()
    local flagg = false
    local maxLevel = GetMaxPlayerLevel()

    if TF.data.setting.auto == false then
        showMessage(Loc["MESSAGE_AUTOFILL"], Loc["THESE_ITEMS"], Loc["TOGGLE_AUTOFILL"], true)
        return true
    end

    if TF.data.setting.guild == true then
        if GetGuildInfo("player") == nil then
            showMessage(Loc["MESSAGE_NO_GUILD"], Loc["THESE_ITEMS"], Loc["TOGGLE_GUILD"], true)
            flagg = true
        elseif TF.guild ~= GetGuildInfo("player") then
            showMessage(Loc["MESSAGE_GUILD"], Loc["THESE_ITEMS"], Loc["TOGGLE_GUILD"], true)
            flagg = true
        end
    end

    if TF.data.setting.level == true and TF.level ~= maxLevel then
        showMessage(Loc["MESSAGE_LEVEL"], Loc["THESE_ITEMS"], getMaxPlayerLevel(), true)
        flagg = true
    end

    if checkStacks(TF.stack) then
        showMessage(Loc["MESSAGE_STACK_CLASS"], Loc["THESE_ITEMS"], setClass(TF.class.file), true)
        flagg = true
    end

    for name in string.gmatch(TF.data.setting.players, "[^\n]+") do
        if string.lower(name) == string.lower(TF.name) then
            showMessage(Loc["MESSAGE_EXCLUDE_PLAYERS"], Loc["THESE_ITEMS"], getName(), true)
            flagg = true
        end
    end

    if TF.guild then
        for guild in string.gmatch(TF.data.setting.guilds, "[^\n]+") do
            if string.lower(guild) == string.lower(TF.guild) then
                local guildName = TF.guild

                showMessage(Loc["MESSAGE_EXCLUDE_GUILDS"], setColor(guildName, "00FF00"), true)
                flagg = true
            end
        end
    end

    if TF.data.setting.master == true then
        local lootmethod, mlPartyID, mlRaidID = GetLootMethod()
        local newLootMaster = nil

        if lootmethod == 'master' then
            if mlRaidID then
                newLootMaster = GetRaidRosterInfo(mlRaidID)
            elseif mlPartyID==0 then
                newLootMaster = UnitName('player')
            elseif mlPartyID then
                newLootMaster = UnitName('party'..mlPartyID)
            end

            if UnitName("player") == newLootMaster then
                showMessage(Loc["MESSAGE_MASTER_LOOTER"], Loc["THESE_ITEMS"], nil, true)
                flagg = true
            end
        end
    end
    return flagg
end